@@ -630,12 +630,29 @@ def _validate_cidr():
         CONF.set_override('network_cidr', '192.0.2.0/24')
 
 
+def _validate_passwords_file():
+    """Disallow updates if the passwords file is missing
+
+    If the undercloud was already deployed, the passwords file needs to be
+    present so passwords that can't be changed are persisted.  If the file
+    is missing it will break the undercloud, so we should fail-fast and let
+    the user know about the problem.
+    """
+    if (os.path.isfile(os.path.expanduser('~/stackrc')) and
+            not os.path.isfile(PATHS.PASSWORD_PATH)):
+        message = ('The %s file is missing.  This will cause all service '
+                   'passwords to change and break the existing undercloud. ' %
+                   PATHS.PASSWORD_PATH)
+        raise validator.FailedValidation(message)
+
+
 def _validate_configuration():
     try:
         _check_hostname()
         _check_memory()
         _check_sysctl()
         _validate_network()
+        _validate_passwords_file()
     except RuntimeError as e:
         LOG.error('ERROR: An error occured during configuration validation, '
                   'please check your host configuration and try again. '
@@ -1196,6 +1213,18 @@ def _post_config(instack_env):
         _post_config_mistral(instack_env, mistral)
 
 
+def _die_tuskar_die():
+    """Remove tuskar* packages
+
+    Make sure to remove tuskar https://bugs.launchpad.net/tripleo/+bug/1691744
+    # openstack-[tuskar, tuskar-ui, tuskar-ui-extras] & python-tuskarclient
+    """
+    try:
+        _run_command(['sudo', 'yum', 'remove', '-y', '*tuskar*'])
+    except subprocess.CalledProcessError as e:
+        LOG.error('Error with tuskar removal task %s - continuing', e.output)
+
+
 def install(instack_root):
     """Install the undercloud
 
@@ -1209,6 +1238,7 @@ def install(instack_root):
     _validate_configuration()
     instack_env = _generate_environment(instack_root)
     _generate_init_data(instack_env)
+    _die_tuskar_die()
     _run_yum_update(instack_env)
     _run_instack(instack_env)
     _run_orc(instack_env)
